@@ -14,8 +14,10 @@
 -- limitations under the License.
 --
 
+--
+-- KULRICE-6916 KRIM_ENTITY_CACHE_T.PRSN_NM is too small
+--
 
--- KULRICE-8177: CONTRIB: Identity Mgmt Section listed as "Undefined"
-update KREW_DOC_TYP_T set LBL = 'Identity Management Document' where
-  DOC_TYP_NM = 'IdentityManagementDocument' and LBL = 'Undefined'
-;
\ No newline at end of file
+ALTER TABLE `krim_entity_cache_t`
+CHANGE COLUMN `PRSN_NM` `PRSN_NM` VARCHAR(255)
+CHARACTER SET 'utf8' COLLATE 'utf8_bin' NULL DEFAULT NULL;
